==> bo4e-0.4.0-py3-none-any.whl: bo4e/enum/messwertstatuszusatz.py <==
# pylint: disable=missing-module-docstring
from bo4e.enum.strenum import StrEnum


class Messwertstatuszusatz(StrEnum):
    """
    Aufzählung von zusätzlichen Informationen zum Status, beispielsweise in Lastgängen oder Zählwerkständen.
    """

    Z84_LEERSTAND = "Z84_LEERSTAND"  #: Z84_LEERSTAND
    Z85_REALERZAEHLERUEBERLAUFGEPRUEFT = "Z85_REALERZAEHLERUEBERLAUFGEPRUEFT"  #: Z85_REALERZAEHLERUEBERLAUFGEPRUEFT
    Z86_PLAUSIBELWGKONTROLLABLESUNG = "Z86_PLAUSIBELWGKONTROLLABLESUNG"  #: Z86_PLAUSIBELWGKONTROLLABLESUNG
    Z87_PLAUSIBELWGKUNDENHINWEIS = "Z87_PLAUSIBELWGKUNDENHINWEIS"  #: Z87_PLAUSIBELWGKUNDENHINWEIS
    ZC3_AUSTAUSCHDESERSATZWERTES = "ZC3_AUSTAUSCHDESERSATZWERTES"  #: ZC3_AUSTAUSCHDESERSATZWERTES
    Z88_VERGLEICHSMESSUNG_GEEICHT = "Z88_VERGLEICHSMESSUNG(GEEICHT)"  #: Z88_VERGLEICHSMESSUNG(GEEICHT)
    Z89_VERGLEICHSMESSUNG_NICHTGEEICHT = "Z89_VERGLEICHSMESSUNG(NICHTGEEICHT)"  #: Z89_VERGLEICHSMESSUNG(NICHTGEEICHT)
    Z90_MESSWERTNACHBILDUNGAUSGEEICHTENWERTEN = (
        "Z90_MESSWERTNACHBILDUNGAUSGEEICHTENWERTEN"  #: Z90_MESSWERTNACHBILDUNGAUSGEEICHTENWERTEN
    )
    Z91_MESSWERTNACHBILDUNGAUSNICHTGEEICHTENWERTEN = (
        "Z91_MESSWERTNACHBILDUNGAUSNICHTGEEICHTENWERTEN"  #: Z91_MESSWERTNACHBILDUNGAUSNICHTGEEICHTENWERTEN
    )
    Z92_INTERPOLATION = "Z92_INTERPOLATION"  #: Z92_INTERPOLATION
    Z93_HALTEWERT = "Z93_HALTEWERT"  #: Z93_HALTEWERT
    Z94_BILANZIERUNGNETZABSCHNITT = "Z94_BILANZIERUNGNETZABSCHNITT"  #: Z94_BILANZIERUNGNETZABSCHNITT
    Z95_HISTORISCHEMESSWERTE = "Z95_HISTORISCHEMESSWERTE"  #: Z95_HISTORISCHEMESSWERTE
    ZJ2_STATISTISCHEMETHODE = "ZJ2_STATISTISCHEMETHODE"  #: ZJ2_STATISTISCHEMETHODE
    Z74_KEINZUGANG = "Z74_KEINZUGANG"  #: Z74_KEINZUGANG
    Z75_KOMMUNIKATIONSSTOERUNG = "Z75_KOMMUNIKATIONSSTOERUNG"  #: Z75_KOMMUNIKATIONSSTOERUNG
    Z76_NETZAUSFALL = "Z76_NETZAUSFALL"  #: Z76_NETZAUSFALL
    Z77_SPANNUNGSAUSFALL = "Z77_SPANNUNGSAUSFALL"  #: Z77_SPANNUNGSAUSFALL
    Z78_GERAETEWECHSEL = "Z78_GERAETEWECHSEL"  #: Z78_GERAETEWECHSEL
    Z79_KALIBRIERUNG = "Z79_KALIBRIERUNG"  #: Z79_KALIBRIERUNG
    Z80_GERAETARBEITETAUSSERHALBDERBETRIEBSBEDINGUNGEN = (
        "Z80_GERAETARBEITETAUSSERHALBDERBETRIEBSBEDINGUNGEN"  #: Z80_GERAETARBEITETAUSSERHALBDERBETRIEBSBEDINGUNGEN
    )
    Z81_MESSEINRICHTUNGGESTOERT_DEFEKT = "Z81_MESSEINRICHTUNGGESTOERT_DEFEKT"  #: Z81_MESSEINRICHTUNGGESTOERT_DEFEKT
    Z82_UNSICHERHEITMESSUNG = "Z82_UNSICHERHEITMESSUNG"  #: Z82_UNSICHERHEITMESSUNG
    Z98_BERUECKSICHTIGUNGSTOERMENGENZAEHLWERK = (
        "Z98_BERUECKSICHTIGUNGSTOERMENGENZAEHLWERK"  #: Z98_BERUECKSICHTIGUNGSTOERMENGENZAEHLWERK
    )
    Z99_MENGENUMWERTUNGUNVOLLSTAENDIG = "Z99_MENGENUMWERTUNGUNVOLLSTAENDIG"  #: Z99_MENGENUMWERTUNGUNVOLLSTAENDIG
    ZA0_UHRZEITGESTELLT_SYNCHRONISATION = "ZA0_UHRZEITGESTELLT_SYNCHRONISATION"  #: ZA0_UHRZEITGESTELLT_SYNCHRONISATION
    ZA1_MESSWERTUNPLAUSIBEL = "ZA1_MESSWERTUNPLAUSIBEL"  #: ZA1_MESSWERTUNPLAUSIBEL
    ZC2_TARIFSCHALTGERAETDEFEKT = "ZC2_TARIFSCHALTGERAETDEFEKT"  #: ZC2_TARIFSCHALTGERAETDEFEKT
    ZC4_IMPULSWERTIGKEITNICHTAUSREICHEND = (
        "ZC4_IMPULSWERTIGKEITNICHTAUSREICHEND"  #: ZC4_IMPULSWERTIGKEITNICHTAUSREICHEND
    )
    ZA3_FALSCHERWANDLERFAKTOR = "ZA3_FALSCHERWANDLERFAKTOR"  #: ZA3_FALSCHERWANDLERFAKTOR
    ZA4_FEHLERHAFTEABLESUNG = "ZA4_FEHLERHAFTEABLESUNG"  #: ZA4_FEHLERHAFTEABLESUNG
    ZA5_AENDERUNGDERBERECHNUNG = "ZA5_AENDERUNGDERBERECHNUNG"  #: ZA5_AENDERUNGDERBERECHNUNG
    ZA6_UMBAUDERMESSLOKATION = "ZA6_UMBAUDERMESSLOKATION"  #: ZA6_UMBAUDERMESSLOKATION
    ZA7_DATENBEARBEITUNGSFEHLER = "ZA7_DATENBEARBEITUNGSFEHLER"  #: ZA7_DATENBEARBEITUNGSFEHLER
    ZA8_BRENNWERTKORREKTUR = "ZA8_BRENNWERTKORREKTUR"  #: ZA8_BRENNWERTKORREKTUR
    ZA9_Z_ZAHL_KORREKTUR = "ZA9_Z-ZAHL-KORREKTUR"  #: ZA9_Z-ZAHL-KORREKTUR
    ZB0_STOERUNG_DEFEKTMESSEINRICHTUNG = "ZB0_STOERUNG_DEFEKTMESSEINRICHTUNG"  #: ZB0_STOERUNG_DEFEKTMESSEINRICHTUNG
    ZB9_AENDERUNGTARIFSCHALTZEITEN = "ZB9_AENDERUNGTARIFSCHALTZEITEN"  #: ZB9_AENDERUNGTARIFSCHALTZEITEN
    ZG3_UMSTELLUNGGASQUALITAET = "ZG3_UMSTELLUNGGASQUALITAET"  #: ZG3_UMSTELLUNGGASQUALITAET

==> bo4e-202401.2.0-py3-none-any.whl: bo4e/enum/messwertstatuszusatz.py <==
# pylint: disable=missing-module-docstring
from bo4e.enum.strenum import StrEnum


class Messwertstatuszusatz(StrEnum):
    """
    Aufzählung von zusätzlichen Informationen zum Status, beispielsweise in Lastgängen oder Zählwerkständen.
    """

    Z84_LEERSTAND = "Z84_LEERSTAND"  #: Z84_LEERSTAND
    Z85_REALERZAEHLERUEBERLAUFGEPRUEFT = "Z85_REALERZAEHLERUEBERLAUFGEPRUEFT"  #: Z85_REALERZAEHLERUEBERLAUFGEPRUEFT
    Z86_PLAUSIBELWGKONTROLLABLESUNG = "Z86_PLAUSIBELWGKONTROLLABLESUNG"  #: Z86_PLAUSIBELWGKONTROLLABLESUNG
    Z87_PLAUSIBELWGKUNDENHINWEIS = "Z87_PLAUSIBELWGKUNDENHINWEIS"  #: Z87_PLAUSIBELWGKUNDENHINWEIS
    ZC3_AUSTAUSCHDESERSATZWERTES = "ZC3_AUSTAUSCHDESERSATZWERTES"  #: ZC3_AUSTAUSCHDESERSATZWERTES
    Z88_VERGLEICHSMESSUNG_GEEICHT = "Z88_VERGLEICHSMESSUNG(GEEICHT)"  #: Z88_VERGLEICHSMESSUNG(GEEICHT)
    Z89_VERGLEICHSMESSUNG_NICHTGEEICHT = "Z89_VERGLEICHSMESSUNG(NICHTGEEICHT)"  #: Z89_VERGLEICHSMESSUNG(NICHTGEEICHT)
    #: Z90_MESSWERTNACHBILDUNGAUSGEEICHTENWERTEN
    Z90_MESSWERTNACHBILDUNGAUSGEEICHTENWERTEN = "Z90_MESSWERTNACHBILDUNGAUSGEEICHTENWERTEN"
    #: Z91_MESSWERTNACHBILDUNGAUSNICHTGEEICHTENWERTEN
    Z91_MESSWERTNACHBILDUNGAUSNICHTGEEICHTENWERTEN = "Z91_MESSWERTNACHBILDUNGAUSNICHTGEEICHTENWERTEN"
    Z92_INTERPOLATION = "Z92_INTERPOLATION"  #: Z92_INTERPOLATION
    Z93_HALTEWERT = "Z93_HALTEWERT"  #: Z93_HALTEWERT
    Z94_BILANZIERUNGNETZABSCHNITT = "Z94_BILANZIERUNGNETZABSCHNITT"  #: Z94_BILANZIERUNGNETZABSCHNITT
    Z95_HISTORISCHEMESSWERTE = "Z95_HISTORISCHEMESSWERTE"  #: Z95_HISTORISCHEMESSWERTE
    ZJ2_STATISTISCHEMETHODE = "ZJ2_STATISTISCHEMETHODE"  #: ZJ2_STATISTISCHEMETHODE
    Z74_KEINZUGANG = "Z74_KEINZUGANG"  #: Z74_KEINZUGANG
    Z75_KOMMUNIKATIONSSTOERUNG = "Z75_KOMMUNIKATIONSSTOERUNG"  #: Z75_KOMMUNIKATIONSSTOERUNG
    Z76_NETZAUSFALL = "Z76_NETZAUSFALL"  #: Z76_NETZAUSFALL
    Z77_SPANNUNGSAUSFALL = "Z77_SPANNUNGSAUSFALL"  #: Z77_SPANNUNGSAUSFALL
    Z78_GERAETEWECHSEL = "Z78_GERAETEWECHSEL"  #: Z78_GERAETEWECHSEL
    Z79_KALIBRIERUNG = "Z79_KALIBRIERUNG"  #: Z79_KALIBRIERUNG
    #: Z80_GERAETARBEITETAUSSERHALBDERBETRIEBSBEDINGUNGEN
    Z80_GERAETARBEITETAUSSERHALBDERBETRIEBSBEDINGUNGEN = "Z80_GERAETARBEITETAUSSERHALBDERBETRIEBSBEDINGUNGEN"
    Z81_MESSEINRICHTUNGGESTOERT_DEFEKT = "Z81_MESSEINRICHTUNGGESTOERT_DEFEKT"  #: Z81_MESSEINRICHTUNGGESTOERT_DEFEKT
    Z82_UNSICHERHEITMESSUNG = "Z82_UNSICHERHEITMESSUNG"  #: Z82_UNSICHERHEITMESSUNG
    #: Z98_BERUECKSICHTIGUNGSTOERMENGENZAEHLWERK
    Z98_BERUECKSICHTIGUNGSTOERMENGENZAEHLWERK = "Z98_BERUECKSICHTIGUNGSTOERMENGENZAEHLWERK"
    Z99_MENGENUMWERTUNGUNVOLLSTAENDIG = "Z99_MENGENUMWERTUNGUNVOLLSTAENDIG"  #: Z99_MENGENUMWERTUNGUNVOLLSTAENDIG
    ZA0_UHRZEITGESTELLT_SYNCHRONISATION = "ZA0_UHRZEITGESTELLT_SYNCHRONISATION"  #: ZA0_UHRZEITGESTELLT_SYNCHRONISATION
    ZA1_MESSWERTUNPLAUSIBEL = "ZA1_MESSWERTUNPLAUSIBEL"  #: ZA1_MESSWERTUNPLAUSIBEL
    ZC2_TARIFSCHALTGERAETDEFEKT = "ZC2_TARIFSCHALTGERAETDEFEKT"  #: ZC2_TARIFSCHALTGERAETDEFEKT
    #: ZC4_IMPULSWERTIGKEITNICHTAUSREICHEND
    ZC4_IMPULSWERTIGKEITNICHTAUSREICHEND = "ZC4_IMPULSWERTIGKEITNICHTAUSREICHEND"
    ZA3_FALSCHERWANDLERFAKTOR = "ZA3_FALSCHERWANDLERFAKTOR"  #: ZA3_FALSCHERWANDLERFAKTOR
    ZA4_FEHLERHAFTEABLESUNG = "ZA4_FEHLERHAFTEABLESUNG"  #: ZA4_FEHLERHAFTEABLESUNG
    ZA5_AENDERUNGDERBERECHNUNG = "ZA5_AENDERUNGDERBERECHNUNG"  #: ZA5_AENDERUNGDERBERECHNUNG
    ZA6_UMBAUDERMESSLOKATION = "ZA6_UMBAUDERMESSLOKATION"  #: ZA6_UMBAUDERMESSLOKATION
    ZA7_DATENBEARBEITUNGSFEHLER = "ZA7_DATENBEARBEITUNGSFEHLER"  #: ZA7_DATENBEARBEITUNGSFEHLER
    ZA8_BRENNWERTKORREKTUR = "ZA8_BRENNWERTKORREKTUR"  #: ZA8_BRENNWERTKORREKTUR
    ZA9_Z_ZAHL_KORREKTUR = "ZA9_Z-ZAHL-KORREKTUR"  #: ZA9_Z-ZAHL-KORREKTUR
    ZB0_STOERUNG_DEFEKTMESSEINRICHTUNG = "ZB0_STOERUNG_DEFEKTMESSEINRICHTUNG"  #: ZB0_STOERUNG_DEFEKTMESSEINRICHTUNG
    ZB9_AENDERUNGTARIFSCHALTZEITEN = "ZB9_AENDERUNGTARIFSCHALTZEITEN"  #: ZB9_AENDERUNGTARIFSCHALTZEITEN
    ZG3_UMSTELLUNGGASQUALITAET = "ZG3_UMSTELLUNGGASQUALITAET"  #: ZG3_UMSTELLUNGGASQUALITAET
